﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;
using System.IO;

namespace rsrtm_read_waveform_example
{
    public partial class rsrtm_read_waveform_example : Form
    {
        private rsrtm m_instrument = null;
        
        public rsrtm_read_waveform_example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void MeasureAndSaveButton_Click(object sender, EventArgs e)
        {
            double[] waveform;
            int actualPoints;
            double initialX, XIncrement;

            StreamWriter saveFileSW = null;
            StringBuilder statusData = new StringBuilder();

            try
            {
                if (SaveMeasuredDataDialog.ShowDialog() == DialogResult.OK)
                {
                    UseWaitCursor = true;
                    System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                    /* initialize driver */
                    if (m_instrument == null)
                        m_instrument = new rsrtm(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                    else if (ResetDevice.Checked)
                        m_instrument.reset();

                    /* configures how the oscilloscope acquires data and fills the waveform record */
                    m_instrument.ConfigureAcquisitionType(rsrtmConstants.Channel1, acquisitionType.SelectedIndex);

                    /* configures the method to reduce the data stream of the ADC to 
                       a stream of waveform points with lower sample rate */
                    m_instrument.ConfigureWaveformArithmetic(rsrtmConstants.Channel1, arithmetics.SelectedIndex);

                    /* configures the time of one acquisition, that is the time across
                   the 10 divisions of the diagram */
                    m_instrument.ConfigureAcquisitionRecord(10 * Convert.ToDouble(horizontalScale.Value), 0);

                    /* configures the axis scaling */
                    m_instrument.ConfigureChannelVerticalScale(rsrtmConstants.Channel1, Convert.ToDouble(verticalScale.Value));
                    m_instrument.ConfigureTimeBase(Convert.ToDouble(horizontalScale.Value), 50);

                    /* trigger configuration */ 
                    m_instrument.ConfigureEdgeTriggerSource(rsrtmConstants.TriggerA, rsrtmConstants.Channel1, 1, Convert.ToDouble(triggerLevel.Value),triggerSlope.SelectedIndex);

                    /* configures the offset voltage, the offset is subtracted to
                       correct an offset-affected signal */
                    m_instrument.ConfigureChannelOffset(rsrtmConstants.Channel1, Convert.ToDouble(offset.Value));

                    Int32 length;
                    m_instrument.QueryWaveformSamplesRange(rsrtmConstants.Channel1, out length);
                    waveform = new double[length];


                    /* This function initiates an acquisition on the channels that you enable with the rsscope_ConfigureChannel function.  It then
                       waits for the acquisition to complete, and returns the waveform for the channel you specify */
                    m_instrument.ReadWaveform(rsrtmConstants.Channel1, length, Convert.ToInt32(this.timeout.Value), waveform, out actualPoints, out initialX, out XIncrement);

                    /* open save file */
                    saveFileSW = new StreamWriter(SaveMeasuredDataDialog.FileName, false, Encoding.Default);

                    saveFileSW.WriteLine("Waveform data");
                    foreach (double data in waveform)
                    {
                        saveFileSW.WriteLine(data.ToString());
                    }
                }
            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }
            finally
            {
                /* close file if opened */
                if (saveFileSW != null)
                {
                    saveFileSW.Close();
                }
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }

        private void rsrtm_read_waveform_example_Load(object sender, EventArgs e)
        {
            this.acquisitionType.SelectedIndex = 0;
            this.arithmetics.SelectedIndex = 0;
            this.triggerSlope.SelectedIndex = 0;
        }
    }
}
